@@ -8,11 +8,12 @@ import os
 from pathlib import Path
 
 from ariadne import gql, load_schema_from_path, make_executable_schema
+from ariadne.validation import cost_validator
 
 from .resolvers import resolvers, scalars
 
 type_defs = gql(
-    # pkg_resources.resource_string("swh.graphql", "schem/schema.graphql").decode()
+    # pkg_resources.resource_string("swh.graphql", "schema/schema.graphql").decode()
     load_schema_from_path(
         os.path.join(Path(__file__).parent.resolve(), "schema", "schema.graphql")
     )
@@ -31,10 +32,32 @@ schema = make_executable_schema(
     resolvers.directory,
     resolvers.directory_entry,
     resolvers.branch_target,
+    resolvers.branch_target_node,
     resolvers.release_target,
+    resolvers.release_target_node,
     resolvers.directory_entry_target,
+    resolvers.directory_entry_target_node,
+    resolvers.resolve_swhid_result,
+    resolvers.origin_search_result,
     resolvers.binary_string,
+    resolvers.date,
     scalars.id_scalar,
     scalars.datetime_scalar,
     scalars.swhid_scalar,
 )
+
+
+def validation_rules(context, document, data):
+    from .server import graphql_cfg
+
+    if context["request"].user.is_authenticated:
+        max_query_cost = graphql_cfg["max_query_cost"]["user"]
+    else:
+        max_query_cost = graphql_cfg["max_query_cost"]["anonymous"]
+
+    if max_query_cost:
+        return [
+            cost_validator(maximum_cost=max_query_cost, variables=data.get("variables"))
+        ]
+    # no limit is applied when max_query_cost is set to 0 or None
+    return None
