@@ -3,14 +3,13 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-from typing import Union
+from typing import TYPE_CHECKING, Optional, Union
 
-from swh.graphql.backends import archive
+from swh.graphql.errors import NullableObjectError
 from swh.graphql.utils import utils
-from swh.model.model import Snapshot
-from swh.storage.interface import PagedResult
+from swh.model.model import CoreSWHID, Snapshot
 
-from .base_connection import BaseConnection
+from .base_connection import BaseConnection, ConnectionData
 from .base_node import BaseSWHNode
 from .origin import OriginNode
 from .visit_status import BaseVisitStatusNode
@@ -21,12 +20,6 @@ class BaseSnapshotNode(BaseSWHNode):
     Base resolver for all the snapshot nodes
     """
 
-    def _get_snapshot_by_id(self, snapshot_id):
-        # Return a Snapshot model object
-        # branches is initialized as empty
-        # Same pattern is used in directory
-        return Snapshot(id=snapshot_id, branches={})
-
     def is_type_of(self):
         # is_type_of is required only when resolving a UNION type
         # This is for ariadne to return the right type
@@ -38,12 +31,11 @@ class SnapshotNode(BaseSnapshotNode):
     Node resolver for a snapshot requested directly with its SWHID
     """
 
-    def _get_node_data(self):
+    def _get_node_data(self) -> Optional[Snapshot]:
         """ """
-        snapshot_id = self.kwargs.get("swhid").object_id
-        if archive.Archive().is_snapshot_available([snapshot_id]):
-            return self._get_snapshot_by_id(snapshot_id)
-        return None
+        swhid = self.kwargs.get("swhid")
+        assert isinstance(swhid, CoreSWHID)
+        return self.archive.get_snapshot(snapshot_id=swhid.object_id, verify=True)
 
 
 class VisitSnapshotNode(BaseSnapshotNode):
@@ -51,12 +43,17 @@ class VisitSnapshotNode(BaseSnapshotNode):
     Node resolver for a snapshot requested from a visit-status
     """
 
+    # Visit snapshot is not using the target indirection,
+    # hence this implementation (not using TargetSnapshotNode)
+
+    _can_be_null = True
     obj: BaseVisitStatusNode
 
     def _get_node_data(self):
-        # self.obj.snapshotSWHID is the requested snapshot SWHID
-        snapshot_id = self.obj.snapshotSWHID.object_id
-        return self._get_snapshot_by_id(snapshot_id)
+        snapshot_id = self.obj.snapshot_id()
+        if snapshot_id is None:
+            raise NullableObjectError()
+        return self.archive.get_snapshot(snapshot_id=snapshot_id, verify=False)
 
 
 class TargetSnapshotNode(BaseSnapshotNode):
@@ -64,13 +61,15 @@ class TargetSnapshotNode(BaseSnapshotNode):
     Node resolver for a snapshot requested as a target
     """
 
-    from .snapshot_branch import SnapshotBranchNode
+    if TYPE_CHECKING:  # pragma: no cover
+        from .target import BranchTargetNode
 
-    obj: Union[BaseVisitStatusNode, SnapshotBranchNode]
+        obj: Union[BranchTargetNode]
+
+    _can_be_null = True
 
     def _get_node_data(self):
-        snapshot_id = self.obj.target_hash
-        return self._get_snapshot_by_id(snapshot_id)
+        return self.archive.get_snapshot(snapshot_id=self.obj.target_hash, verify=False)
 
 
 class OriginSnapshotConnection(BaseConnection):
@@ -82,10 +81,15 @@ class OriginSnapshotConnection(BaseConnection):
 
     _node_class = BaseSnapshotNode
 
-    def _get_paged_result(self) -> PagedResult:
-        results = archive.Archive().get_origin_snapshots(self.obj.url)
-        snapshots = [Snapshot(id=snapshot, branches={}) for snapshot in results]
+    def _get_connection_data(self) -> ConnectionData:
+        results = self.archive.get_origin_snapshots(self.obj.url)
+        snapshots = [
+            self.archive.get_snapshot(snapshot_id=snapshot, verify=False)
+            for snapshot in results
+        ]
         # FIXME, using dummy(local) pagination, move pagination to backend
         # To remove localpagination, just drop the paginated call
         # STORAGE-TODO
-        return utils.paginated(snapshots, self._get_first_arg(), self._get_after_arg())
+        return utils.get_local_paginated_data(
+            snapshots, self._get_first_arg(), self._get_after_arg()
+        )
